@@ -42,8 +42,8 @@ sub meta_merge {
 	},
 	resources	=> {
 	    bugtracker	=> {
-                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack',
-#                mailto  => 'wyant@cpan.org',
+		web	=> 'https://github.com/trwyant/perl-Astro-SpaceTrack/issues',
+		mailto	=> 'wyant@cpan.org',
             },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
@@ -244,7 +244,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2019 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
